package com.huimv.location.utils;

import org.springframework.stereotype.Component;

import java.io.UnsupportedEncodingException;
import java.math.BigDecimal;
import java.math.RoundingMode;

/**
 * @Project : huimv.shiwan
 * @Package : com.huimv.biosafety.uface.controller
 * @Description : TODO
 * @Version : 1.0
 * @Author : ZhuoNing
 * @Create : 2020-12-25
 **/
@Component
public class StringUtils {
    private final String ENCODE = "UTF-8";


    public double getBytes(String text) throws UnsupportedEncodingException {
        return text.getBytes(ENCODE).length;
    }

    public double getKBytes(String text) throws UnsupportedEncodingException {
        return text.getBytes(ENCODE).length / 1024;
    }

    public double getMBytes(String text) throws UnsupportedEncodingException {
        return text.getBytes(ENCODE).length / (1024 * 1024);
    }

    /**
     * @Method : getTextBytes
     * @Description : 获取文本内容的字节数，单位是B,MB,GB，编码类型是:UTF-8
     * @Params : [text, encode]
     * @Return : java.lang.String
     * @Author : ZhuoNing
     * @Date : 2021/9/22
     * @Time : 14:42
     */
    public String getTextBytes(String text, String encode) throws UnsupportedEncodingException {
        long byteSize = text.getBytes(ENCODE).length;
//        byteSize = 1025;
        long kbyteSize = 0;
        long mbyteSize = 0;
        long gbyteSize = 0;
//        System.out.println("byteSize>>" + byteSize);
        //如果字节数少于1024，则直接以B为单位，否则先除于1024，后3位因太少无意义
        if (byteSize < 1024) {
            return String.valueOf(byteSize) + "B";
        } else {
            kbyteSize = byteSize / 1024;
            if (byteSize % 1024 > 0) {
                kbyteSize++;
            }
        }
        //如果原字节数除于1024之后，少于1024，则可以直接以KB作为单位
        //因为还没有到达要使用另一个单位的时候
        //接下去以此类推
        if (kbyteSize < 1024) {
            return String.valueOf(kbyteSize) + "KB";
        } else {
            mbyteSize = kbyteSize / 1024;
            if (kbyteSize % 1024 > 0) {
                mbyteSize++;
            }
        }
        if (mbyteSize < 1024) {
            //因为如果以MB为单位的话，要保留最后1位小数，
            //因此，把此数乘以100之后再取余
            mbyteSize = mbyteSize * 100;
            return String.valueOf((mbyteSize / 100)) + "."
                    + String.valueOf((mbyteSize % 100)) + "MB";
        } else {
            //否则如果要以GB为单位的，先除于1024再作同样的处理
            gbyteSize = mbyteSize * 100 / 1024;
            return String.valueOf((gbyteSize / 100)) + "."
                    + String.valueOf((gbyteSize % 100)) + "GB";
        }

    }
}
